@@ -2,6 +2,7 @@ package integration_test
 
 import (
 	"strings"
+	"time"
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
@@ -46,7 +47,7 @@ var _ = Describe("Flags Specs", func() {
 		Ω(output).Should(ContainSubstring("Detected pending specs and --fail-on-pending is set"))
 	})
 
-	It("should run the race detector when told to", Label("slow"), func() {
+	It("should run the race detector when told to", Label("slow"), NodeTimeout(2*time.Minute), func(ctx SpecContext) {
 		if !raceDetectorSupported() {
 			Skip("race detection is not supported")
 		}
@@ -66,6 +67,12 @@ var _ = Describe("Flags Specs", func() {
 		Ω(orders[0]).ShouldNot(BeNumerically("<", orders[1]))
 	})
 
+	It("should consistently pass in a zero seed when asked to", func() {
+		fm.MountFixture("seed")
+		session := startGinkgo(fm.PathTo("seed"), "--no-color", "--seed=0", "--nodes=2")
+		Eventually(session).Should(gexec.Exit(0))
+	})
+
 	It("should pass additional arguments in", func() {
 		session := startGinkgo(fm.PathTo("flags"), "--", "--customFlag=madagascar")
 		Eventually(session).Should(gexec.Exit(1))
